@@ -248,7 +248,7 @@ class QuickbooksCore(SitesCore):
         self.browser.click_element_when_visible('//div[text()="Due on receipt"]')
 
         invoice_date: str = self.browser.get_value('//input[@data-automation-id="input-creation-date-sales"]')
-        invoice_number: str = 'Test Number'
+        invoice_number: str = '1234'
         if is_prod:
             self.browser.click_element_when_visible('//button[text()="Save and send"]')
             self.wait_element('//button[text()="Send and close"]')
